@@ -12,7 +12,8 @@ import Types
 ----------------------------------------------------------------
 
 checkSyntax :: Options -> String -> IO String
-checkSyntax opt file = unlines <$> check opt file
+checkSyntax opt file = do
+  unlines <$> check opt file
 
 ----------------------------------------------------------------
 
@@ -24,5 +25,4 @@ check opt fileName = withGHC $ checkIt `gcatch` handleErrMsg
         setTargetFile file
         load LoadAllTargets
         liftIO readLog
-    options = ["-Wall","-fno-warn-unused-do-bind"]
-           ++ map ("-i" ++) (checkIncludes opt)
+    options = ["-Wall","-fno-warn-unused-do-bind"] ++ ghcOpts opt
